@@ -4,19 +4,18 @@
 // SPDX-License-Identifier: LGPL-3.0-or-later
 
 #pragma once
-#include "abstractapplication.h"
+
 #include "calendarconfig.h"
 
 #include <Akonadi/ETMCalendar>
-#include <KActionCollection>
 #include <QActionGroup>
 #include <QObject>
 #include <QWindow>
+#include <abstractmerkuroapplication.h>
 
 class QQuickWindow;
-class QSortFilterProxyModel;
 
-class CalendarApplication : public AbstractApplication
+class CalendarApplication : public AbstractMerkuroApplication
 {
     Q_OBJECT
 
@@ -36,9 +35,8 @@ public:
     Q_ENUM(Mode)
 
     explicit CalendarApplication(QObject *parent = nullptr);
-    ~CalendarApplication() override;
 
-    QList<KActionCollection *> actionCollections() const override;
+    QList<KirigamiActionCollection *> actionCollections() const override;
 
     Q_INVOKABLE void saveWindowGeometry(QQuickWindow *window);
     QWindow *window() const;
@@ -82,10 +80,9 @@ private Q_SLOTS:
 
 private:
     void setupActions() override;
-    void toggleMenubar();
     bool showMenubar() const;
 
-    KActionCollection *mSortCollection = nullptr;
+    KirigamiActionCollection *mSortCollection = nullptr;
     QWindow *m_window = nullptr;
     QActionGroup *const m_viewGroup;
     QActionGroup *m_todoViewOrderGroup = nullptr;
