@@ -7,6 +7,7 @@
 #include <KAboutData>
 #include <KConfig>
 #include <KConfigGroup>
+#include <KCrash>
 #include <KDBusService>
 #include <KLocalizedContext>
 #include <KLocalizedString>
@@ -22,6 +23,9 @@
 #include <QQmlContext>
 #include <QQuickStyle>
 #include <QQuickWindow>
+#if KI18N_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+#include <KLocalizedQmlContext>
+#endif
 #define HAVE_KICONTHEME __has_include(<KIconTheme>)
 #if HAVE_KICONTHEME
 #include <KIconTheme>
@@ -78,7 +82,8 @@ int main(int argc, char *argv[])
     aboutData.addAuthor(i18nc("@info:credit", "Carl Schwan"),
                         i18nc("@info:credit", "Maintainer"),
                         QStringLiteral("carl@carlschwan.eu"),
-                        QStringLiteral("https://carlschwan.eu"));
+                        QStringLiteral("https://carlschwan.eu"),
+                        QUrl(QStringLiteral("https://carlschwan.eu/avatar.png")));
     aboutData.addAuthor(i18nc("@info:credit", "Clau Cambra"),
                         i18nc("@info:credit", "Maintainer"),
                         QStringLiteral("claudio.cambra@gmail.com"),
@@ -88,6 +93,7 @@ int main(int argc, char *argv[])
                         QStringLiteral("kinofhek@gmail.com"),
                         QStringLiteral("https://fhek.gitlab.io"));
     KAboutData::setApplicationData(aboutData);
+    KCrash::initialize();
     QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.merkuro.calendar")));
 
     QCommandLineParser parser;
@@ -125,7 +131,11 @@ int main(int argc, char *argv[])
         }
     });
 
+#if KI18N_VERSION < QT_VERSION_CHECK(6, 8, 0)
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
+#else
+    engine.rootContext()->setContextObject(new KLocalizedQmlContext(&engine));
+#endif
     engine.load(QUrl(QStringLiteral("qrc:/main.qml")));
 
     if (engine.rootObjects().isEmpty()) {
