@@ -11,7 +11,9 @@ class TimeZoneListModel : public QAbstractListModel
     Q_OBJECT
 
 public:
-    enum Roles { IdRole = Qt::UserRole + 1 };
+    enum Roles {
+        IdRole = Qt::UserRole + 1
+    };
     Q_ENUM(Roles)
 
     explicit TimeZoneListModel(QObject *parent = nullptr);
