@@ -3,6 +3,7 @@
 
 #include "../config-merkuro.h"
 #include <KAboutData>
+#include <KCrash>
 #include <KDBusService>
 #include <KLocalizedContext>
 #include <KLocalizedString>
@@ -19,6 +20,11 @@
 #include <KIconTheme>
 #endif
 
+#include <Libkleo/KeyCache>
+#if KI18N_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+#include <KLocalizedQmlContext>
+#endif
+
 #define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
 #if HAVE_STYLE_MANAGER
 #include <KStyleManager>
@@ -70,12 +76,14 @@ int main(int argc, char *argv[])
     aboutData.addAuthor(i18nc("@info:credit", "Carl Schwan"),
                         i18nc("@info:credit", "Maintainer"),
                         QStringLiteral("carl@carlschwan.eu"),
-                        QStringLiteral("https://carlschwan.eu"));
+                        QStringLiteral("https://carlschwan.eu"),
+                        QUrl(QStringLiteral("https://carlschwan.eu/avatar.png")));
     aboutData.addAuthor(i18nc("@info:credit", "Clau Cambra"),
                         i18nc("@info:credit", "Maintainer"),
                         QStringLiteral("claudio.cambra@gmail.com"),
                         QStringLiteral("https://claudiocambra.com"));
     KAboutData::setApplicationData(aboutData);
+    KCrash::initialize();
     QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.merkuro.contact")));
 
     QCommandLineParser parser;
@@ -86,7 +94,11 @@ int main(int argc, char *argv[])
     KDBusService service(KDBusService::Unique);
 
     QQmlApplicationEngine engine;
+#if KI18N_VERSION < QT_VERSION_CHECK(6, 8, 0)
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
+#else
+    engine.rootContext()->setContextObject(new KLocalizedQmlContext(&engine));
+#endif
     engine.loadFromModule("org.kde.merkuro.contact", "Main");
 
     QObject::connect(&service, &KDBusService::activateRequested, &engine, [&engine](const QStringList & /*arguments*/, const QString & /*workingDirectory*/) {
@@ -104,5 +116,8 @@ int main(int argc, char *argv[])
         return -1;
     }
 
+    auto keyCache = Kleo::KeyCache::mutableInstance();
+    keyCache->startKeyListing();
+
     return app.exec();
 }
