@@ -7,30 +7,32 @@
 #include <QIcon>
 
 MailApplication::MailApplication(QObject *parent)
-    : AbstractApplication(parent)
+    : AbstractMerkuroApplication(parent)
 {
     setupActions();
 }
 
+MailApplication::~MailApplication() = default;
+
 void MailApplication::setupActions()
 {
-    AbstractApplication::setupActions();
+    AbstractMerkuroApplication::setupActions();
 
     auto actionName = QLatin1StringView("create_mail");
     if (KAuthorized::authorizeAction(actionName)) {
-        auto action = mCollection->addAction(actionName, this, &MailApplication::createNewMail);
+        auto action = mainCollection()->addAction(actionName, this, &MailApplication::createNewMail);
         action->setText(i18n("New Mail…"));
         action->setIcon(QIcon::fromTheme(QStringLiteral("mail-message-new")));
     }
 
-    mCollection->readSettings();
-}
+    const auto checkMailActionName = QLatin1StringView("check_mail");
+    if (KAuthorized::authorizeAction(checkMailActionName)) {
+        const auto action = mainCollection()->addAction(checkMailActionName, this, &MailApplication::checkMail);
+        action->setText(i18n("Check Mail"));
+        action->setIcon(QIcon::fromTheme(QStringLiteral("mail-receive")));
+    }
 
-QList<KActionCollection *> MailApplication::actionCollections() const
-{
-    return {
-        mCollection,
-    };
+    readSettings();
 }
 
 #include "moc_mailapplication.cpp"
