@@ -32,7 +32,7 @@ public:
 
     explicit MailModel(QObject *parent = nullptr);
     [[nodiscard]] QHash<int, QByteArray> roleNames() const override;
-    virtual QVariant data(const QModelIndex &index, int role) const override;
+    QVariant data(const QModelIndex &index, int role) const override;
     bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
 
     Q_INVOKABLE void updateMessageStatus(int row, MessageStatus messageStatus);
